@@ -27,7 +27,7 @@ public:
     {
     }
 
-    QVariant data(const QModelIndex &index, int role) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override
     {
         QVariant d;
         if (role == Qt::DisplayRole || role == Qt::EditRole) {
@@ -123,7 +123,8 @@ void IncidenceResource::bookResource()
     if (mUi->mNewResource->text().trimmed().isEmpty()) {
         return;
     }
-    QString name, email;
+    QString name;
+    QString email;
     KEmailAddress::extractEmailAddressAndName(mUi->mNewResource->text(), email, name);
     KCalendarCore::Attendee attendee(name, email);
     attendee.setCuType(KCalendarCore::Attendee::Resource);
